libtab library
Classes
- ChartPositioning
- Container and calculator of Canvas spacing values for strings and notes
- ChordChartDisplay
- Displays a chart of a Chord and Instrument finger formation specified by a ChordNoteSet
- ChordChartPainter
- Paints a chart of a Chord and Instrument finger formation specified by a ChordNoteSet
- ChordNoteSet
- ChordNoteSet contains Note data for an Instrument's finger positioning for a Chord. A Chord and Instrument combination without chart data will be rendered by ChordChartDisplay with a user friendly message.
- Measure
- MeasureChartPainter
- Paints a Measure of tab data that can be styled with TabContext
- MeasureDisplay
- Displays a Measure of tab data that can be styled with TabContext
- MeasureNotePainter
- Note
- TabContext
- Timing